# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Resource types

* [`credential`](#credential): Manages Credential Manager credentials on Windows systems.

### Functions

* [`conjur::secret`](#conjursecret): Function to retrieve a Conjur / DAP secret

## Resource types

### `credential`

Manages Credential Manager credentials on Windows systems.

#### Properties

The following properties are available in the `credential` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `username`

The identity used to authenticate to the Conjur / DAP instance

##### `value`

The API key matching the Conjur / DAP identity

#### Parameters

The following parameters are available in the `credential` type.

##### `provider`

The specific backend to use for this `credential` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

##### `target`

Conjur / DAP URL

## Functions

### `conjur::secret`

Type: Ruby 4.x API

Function to retrieve a Conjur / DAP secret

#### Examples

##### Agent-based identity invocation

```puppet
Deferred(conjur::secret, ['production/postgres/password'])
```

##### Server-based identity invocation

```puppet
$sslcert = @("EOT")
-----BEGIN CERTIFICATE-----
...
-----END CERTIFICATE-----
|-EOT

$dbpass = Deferred(conjur::secret, ['production/postgres/password', {
  appliance_url => "https://my.conjur.org",
  account => "myaccount",
  authn_login => "host/myhost",
  authn_api_key => Sensitive("2z9mndg1950gcx1mcrs6w18bwnp028dqkmc34vj8gh2p500ny1qk8n"),
  ssl_certificate => $sslcert
}])
```

#### `conjur::secret(String $variable_id, Optional[Hash] $options)`

Function to retrieve a Conjur / DAP secret

Returns: `Sensitive` Value of the Conjur variable.

##### Examples

###### Agent-based identity invocation

```puppet
Deferred(conjur::secret, ['production/postgres/password'])
```

###### Server-based identity invocation

```puppet
$sslcert = @("EOT")
-----BEGIN CERTIFICATE-----
...
-----END CERTIFICATE-----
|-EOT

$dbpass = Deferred(conjur::secret, ['production/postgres/password', {
  appliance_url => "https://my.conjur.org",
  account => "myaccount",
  authn_login => "host/myhost",
  authn_api_key => Sensitive("2z9mndg1950gcx1mcrs6w18bwnp028dqkmc34vj8gh2p500ny1qk8n"),
  ssl_certificate => $sslcert
}])
```

##### `variable_id`

Data type: `String`

Conjur / DAP variable ID that you want the value of.

##### `options`

Data type: `Optional[Hash]`

Optional parameter specifying server identity overrides
The following keys are supported in the options hash:
- appliance_url: The URL of the Conjur or DAP instance..
- account: Name of the Conjur account that contains this variable.
- authn_login: The identity you are using to authenticate to the Conjur / DAP instance.
- authn_api_key: The API key of the identity you are using to authenticate with (must be Sensitive type).
- cert_file: The absolute path to CA certificate chain for the DAP instance on the agent. This variable overrides `ssl_certificate`.
- ssl_certificate: The _raw_ PEM-encoded x509 CA certificate chain for the DAP instance. Overwritten by the contents read from `cert_file` when it is present.
- version: Conjur API version, defaults to 5.

